@@ -1,14 +1,14 @@
 <?php
 /**
- * $Horde: horde/admin/user.php,v 1.47 2004/06/14 21:04:17 jan Exp $
+ * $Horde: horde/admin/user.php,v 1.47.10.2 2005/02/08 19:38:36 chuck Exp $
  *
- * Copyright 1999-2004 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
 
-define('HORDE_BASE', dirname(__FILE__) . '/..');
+@define('HORDE_BASE', dirname(__FILE__) . '/..');
 require_once HORDE_BASE . '/lib/base.php';
 require_once 'Horde/Menu.php';
 require_once 'Horde/Form.php';
@@ -105,6 +105,7 @@ case 'remove':
             $notification->push(sprintf(_("Successfully removed '%s' from the system."), $f_user_name), 'horde.success');
         }
     }
+    $vars->remove('user_name');
     break;
 
 case 'clear_f':
@@ -123,6 +124,7 @@ case 'clear':
             $notification->push(sprintf(_("Successfully cleared data for user '%s' from the system."), $f_user_name), 'horde.success');
         }
     }
+    $vars->remove('user_name');
     break;
 
 case 'update_f':
@@ -166,6 +168,7 @@ case 'update':
         $notification->push(sprintf(_("Successfully updated '%s'"),
                                     $user_name_2), 'horde.success');
     }
+    $vars->remove('user_name');
     break;
 
 case 'approve_f':
@@ -173,18 +176,17 @@ case 'approve_f':
     $info = $thisSignup->getData();
 
     $vars->set('password',
-                  array('original' => $info['password'],
-                        'confirm' => $info['password']));
+               array('original' => $info['password'],
+                     'confirm' => $info['password']));
     unset($info['password']);
     $vars->set('extra', $info);
 
     $vars->set('removeQueuedSignup', true);
     $addForm->addHidden('', 'removeQueuedSignup', 'boolean', true);
-
     break;
 
 case 'removequeued_f':
-    $f_user_name = Util::getFormData('user_name'); 
+    $f_user_name = Util::getFormData('user_name');
     $removequeued_form = true;
     break;
 
@@ -228,7 +230,7 @@ if ($auth->hasCapability('list')) {
     /* If we aren't supplied with a page number, default to page 0. */
     $page = Util::getFormData('page', 0);
     $search_pattern = Util::getFormData('search_pattern', '');
-    
+
     $users = $auth->listUsers();
     if (is_a($users, 'PEAR_Error')) {
         Horde::fatal($users, __FILE__, __LINE__);
@@ -244,16 +246,16 @@ if ($auth->hasCapability('list')) {
 
     $numitem = count($users);
     $perpage = 20;
-    
+
     $min = $page * $perpage;
     while ($min > $numitem) {
         $page--;
         $min = $page * $perpage;
     }
     $max = $min + $perpage;
-    
+
     $start = ($page * $perpage) + 1;
-    $end = min($numitem, $start + $perpage - 1);    
+    $end = min($numitem, $start + $perpage - 1);
 
     require HORDE_TEMPLATES . '/admin/user/list.inc';
 } else {
