@@ -13,11 +13,10 @@
  * See the enclosed file COPYING for license information (LGPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * $Horde: framework/File_PDF/PDF.php,v 1.18.10.1 2005/01/03 12:18:59 jan Exp $
+ * $Horde: framework/File_PDF/PDF.php,v 1.18.10.3 2005/03/04 16:14:24 jan Exp $
  *
  * @author  Olivier Plathey <olivier@fpdf.org>
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.18.10.1 $
  * @package File_PDF
  */
 class File_PDF {
@@ -379,98 +378,124 @@ class File_PDF {
      * methods (except for the font sizes).
      *
      * Example:
-     * $pdf = &File_PDF::factory('P', 'mm', 'A4');
+     * $pdf = &File_PDF::factory(array('orientation' => 'P',
+     *                                 'unit' => 'mm',
+     *                                 'format' => 'A4'));
      *
      * @access public
      *
-     * @param optional string $orientation  Default page orientation.
-     *                                      Possible values are (case
-     *                                      insensitive):
-     *                                        - P or Portrait (default)
-     *                                        - L or Landscape
-     * @param optional string $unit         User measure units. Possible values
-     *                                      values are:
-     *                                        - pt: point
-     *                                        - mm: millimeter (default)
-     *                                        - cm: centimeter
-     *                                        - in: inch
-     *                                      A point equals 1/72 of inch, that
-     *                                      is to say about 0.35 mm (an inch
-     *                                      being 2.54 cm). This is a very
-     *                                      common unit in typography; font
-     *                                      sizes are expressed in that unit.
-     * @param optional mixed format         The format used for pages. It can
-     *                                      be either one of the following
-     *                                      values (case insensitive):
-     *                                        - A3
-     *                                        - A4 (default)
-     *                                        - A5
-     *                                        - Letter
-     *                                        - Legal
-     *                                      or a custom format in the form of
-     *                                      a two-element array containing the
-     *                                      width and the height (expressed in
-     *                                      the unit given by unit).
+     * @param array $params  A hash with parameters for the created PDF object.
+     *                       Possible parameters are:
+     *                       orientation - Default page orientation. Possible
+     *                       values are (case insensitive):
+     *                       <pre>
+     *                         - P or Portrait (default)
+     *                         - L or Landscape
+     *                       </pre>
+     *                       unit - User measure units. Possible values values
+     *                       are:
+     *                       <pre>
+     *                         - pt: point
+     *                         - mm: millimeter (default)
+     *                         - cm: centimeter
+     *                         - in: inch
+     *                       </pre>
+     *                       A point equals 1/72 of inch, that is to say about
+     *                       0.35 mm (an inch being 2.54 cm). This is a very
+     *                       common unit in typography; font sizes are
+     *                       expressed in that unit.
+     *                       format - The format used for pages. It can be
+     *                       either one of the following values (case
+     *                       insensitive):
+     *                       <pre>
+     *                         - A3
+     *                         - A4 (default)
+     *                         - A5
+     *                         - Letter
+     *                         - Legal
+     *                       </pre>
+     *                       or a custom format in the form of a two-element
+     *                       array containing the width and the height
+     *                       (expressed in the unit given by the unit
+     *                       parameter).
+     * @param string $class  The concrete class name to return an instance of.
+     *                       Defaults to File_PDF.
      */
-    function &factory($orientation = 'P', $unit = 'mm', $format = 'A4')
+    function &factory($params = array(), $class = 'File_PDF')
     {
         /* Check for PHP locale-related bug. */
         if (1.1 == 1) {
             return File_PDF::raiseError('Do not alter the locale before including the class file.');
         }
 
+        /* Default parameters. */
+        $defaults = array('orientation' => 'P', 'unit' => 'mm', 'format' => 'A4');
+
+        /* Backward compatibility with old method signature. */
+        /* Should be removed a few versions later. */
+        if (!is_array($params)) {
+            $class = 'File_PDF';
+            $params = $defaults;
+            $names = array_keys($defaults);
+            for ($i = 0; $i < func_num_args(); $i++) {
+                $params[$names[$i]] = func_get_arg($i);
+            }
+        } else {
+            $params = array_merge($defaults, $params);
+        }
+
         /* Create the PDF object. */
-        $pdf = &new File_PDF();
+        $pdf = &new $class();
 
         /* Scale factor. */
-        if ($unit == 'pt') {
+        if ($params['unit'] == 'pt') {
             $pdf->_scale = 1;
-        } elseif ($unit == 'mm') {
+        } elseif ($params['unit'] == 'mm') {
             $pdf->_scale = 72 / 25.4;
-        } elseif ($unit == 'cm') {
+        } elseif ($params['unit'] == 'cm') {
             $pdf->_scale = 72 / 2.54;
-        } elseif ($unit == 'in') {
+        } elseif ($params['unit'] == 'in') {
             $pdf->_scale = 72;
         } else {
-            return File_PDF::raiseError(sprintf('Incorrect units: %s', $unit));
+            return File_PDF::raiseError(sprintf('Incorrect units: %s', $params['unit']));
         }
         /* Page format. */
-        if (is_string($format)) {
-            $format = strtolower($format);
-            if ($format == 'a3') {
-                $format = array(841.89, 1190.55);
-            } elseif ($format == 'a4') {
-                $format = array(595.28, 841.89);
-            } elseif ($format == 'a5') {
-                $format = array(420.94, 595.28);
-            } elseif ($format == 'letter') {
-                $format = array(612, 792);
-            } elseif ($format == 'legal') {
-                $format = array(612, 1008);
+        if (is_string($params['format'])) {
+            $params['format'] = strtolower($params['format']);
+            if ($params['format'] == 'a3') {
+                $params['format'] = array(841.89, 1190.55);
+            } elseif ($params['format'] == 'a4') {
+                $params['format'] = array(595.28, 841.89);
+            } elseif ($params['format'] == 'a5') {
+                $params['format'] = array(420.94, 595.28);
+            } elseif ($params['format'] == 'letter') {
+                $params['format'] = array(612, 792);
+            } elseif ($params['format'] == 'legal') {
+                $params['format'] = array(612, 1008);
             } else {
-                return File_PDF::raiseError(sprintf('Unknown page format: %s', $format));
+                return File_PDF::raiseError(sprintf('Unknown page format: %s', $params['format']));
             }
-            $pdf->fwPt = $format[0];
-            $pdf->fhPt = $format[1];
+            $pdf->fwPt = $params['format'][0];
+            $pdf->fhPt = $params['format'][1];
         } else {
-            $pdf->fwPt = $format[0] * $pdf->_scale;
-            $pdf->fhPt = $format[1] * $pdf->_scale;
+            $pdf->fwPt = $params['format'][0] * $pdf->_scale;
+            $pdf->fhPt = $params['format'][1] * $pdf->_scale;
         }
         $pdf->fw = $pdf->fwPt / $pdf->_scale;
         $pdf->fh = $pdf->fhPt / $pdf->_scale;
 
         /* Page orientation. */
-        $orientation = strtolower($orientation);
-        if ($orientation == 'p' || $orientation == 'portrait') {
+        $params['orientation'] = strtolower($params['orientation']);
+        if ($params['orientation'] == 'p' || $params['orientation'] == 'portrait') {
             $pdf->_default_orientation = 'P';
             $pdf->wPt = $pdf->fwPt;
             $pdf->hPt = $pdf->fhPt;
-        } elseif ($orientation == 'l' || $orientation == 'landscape') {
+        } elseif ($params['orientation'] == 'l' || $params['orientation'] == 'landscape') {
             $pdf->_default_orientation = 'L';
             $pdf->wPt = $pdf->fhPt;
             $pdf->hPt = $pdf->fwPt;
         } else {
-            return File_PDF::raiseError(sprintf('Incorrect orientation: %s', $orientation));
+            return File_PDF::raiseError(sprintf('Incorrect orientation: %s', $params['orientation']));
         }
         $pdf->_current_orientation = $pdf->_default_orientation;
         $pdf->w = $pdf->wPt / $pdf->_scale;
@@ -801,11 +826,11 @@ class File_PDF {
         $dc = $this->_draw_color;
         $fc = $this->_fill_color;
         if ($this->_page > 0) {
-            /*  Page footer. */
+            /* Page footer. */
             $this->_in_footer = true;
             $this->footer();
             $this->_in_footer = false;
-            /*  Close page. */
+            /* Close page. */
             $this->_endPage();
         }
         /* Start new page. */
@@ -956,9 +981,9 @@ class File_PDF {
     function setFillColor($cs = 'rgb', $c1, $c2 = 0, $c3 = 0, $c4 = 0)
     {
         $cs = strtolower($cs);
-        if ($cs = 'rgb') {
+        if ($cs == 'rgb') {
             $this->_fill_color = sprintf('%.3f %.3f %.3f rg', $c1, $c2, $c3);
-        } elseif ($cs = 'cmyk') {
+        } elseif ($cs == 'cmyk') {
             $this->_fill_color = sprintf('%.3f %.3f %.3f %.3f k', $c1, $c2, $c3, $c4);
         } else {
             $this->_fill_color = sprintf('%.3f g', $c1);
@@ -997,9 +1022,9 @@ class File_PDF {
     function setDrawColor($cs = 'rgb', $c1, $c2 = 0, $c3 = 0, $c4 = 0)
     {
         $cs = strtolower($cs);
-        if ($cs = 'rgb') {
+        if ($cs == 'rgb') {
             $this->_draw_color = sprintf('%.3f %.3f %.3f RG', $c1, $c2, $c3);
-        } elseif ($cs = 'cmyk') {
+        } elseif ($cs == 'cmyk') {
             $this->_draw_color = sprintf('%.3f %.3f %.3f %.3f K', $c1, $c2, $c3, $c4);
         } else {
             $this->_draw_color = sprintf('%.3f G', $c1);
@@ -1486,7 +1511,7 @@ class File_PDF {
         $height = $this->_toPt($height);
 
         /* Save link to page links array. */
-        $this->_links($x, $y, $width, $height, $link);
+        $this->_link($x, $y, $width, $height, $link);
     }
 
     /**
@@ -2207,8 +2232,8 @@ class File_PDF {
      *
      * @access public
      *
-     * @param optional string $filename  The filename for the output file.
-     * @param optional bool $inline      True if inline, false if attachment.
+     * @param string $filename  The filename for the output file.
+     * @param bool $inline      True if inline, false if attachment.
      */
     function output($filename = 'unknown.pdf', $inline = false)
     {
@@ -2241,10 +2266,15 @@ class File_PDF {
      *
      * @access public
      *
-     * @param optional string $filename  The filename for the output file.
+     * @param string $filename  The filename for the output file.
      */
     function save($filename = 'unknown.pdf')
     {
+        /* Check whether file has been closed. */
+        if ($this->_state < 3) {
+            $this->close();
+        }
+
         $f = fopen($filename, 'wb');
         if (!$f) {
             return $this->raiseError(sprintf('Unable to save PDF file: %s', $filename));
@@ -2368,7 +2398,7 @@ class File_PDF {
         $mqr = get_magic_quotes_runtime();
         set_magic_quotes_runtime(0);
         foreach ($this->_font_files as $file => $info) {
-            /*  Font file embedding. */
+            /* Font file embedding. */
             $this->_newobj();
             $this->_font_files[$file]['n'] = $this->_n;
             $size = filesize($file);
@@ -2430,7 +2460,7 @@ class File_PDF {
                 }
                 $this->_out($s . ']');
                 $this->_out('endobj');
-                /*  Descriptor. */
+                /* Descriptor. */
                 $this->_newobj();
                 $s = '<</Type /FontDescriptor /FontName /' . $name;
                 foreach ($font['desc'] as $k => $v) {
@@ -2481,7 +2511,7 @@ class File_PDF {
             $this->_putStream($info['data']);
             $this->_out('endobj');
 
-            /*  Palette. */
+            /* Palette. */
             if ($info['cs'] == 'Indexed') {
                 $this->_newobj();
                 $pal = ($this->_compress) ? gzcompress($info['pal']) : $info['pal'];
@@ -2813,7 +2843,7 @@ class File_PDF {
 
     function _out($s)
     {
-        /*  Add a line to the document. */
+        /* Add a line to the document. */
         if ($this->_state == 2) {
             $this->_pages[$this->_page] .= $s . "\n";
         } else {
