@@ -9,7 +9,7 @@ require_once 'Horde/Form/Renderer.php';
  * new users sign themselves up into the horde installation, depending
  * on how the admin has configured Horde.
  *
- * $Horde: framework/Auth/Auth/Signup.php,v 1.38.2.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/Signup.php,v 1.38.2.2 2005/01/19 15:05:03 jan Exp $
  *
  * Copyright 2002-2005 Marko Djukic <marko@oblo.com>
  *
@@ -17,7 +17,7 @@ require_once 'Horde/Form/Renderer.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.38.2.1 $
+ * @version $Revision: 1.38.2.2 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -97,7 +97,7 @@ class Auth_Signup {
                                      array($info['user_name'], $info['extra']));
             if (!$added || is_a($added, 'PEAR_Error')) {
                 Horde::logMessage($added, __FILE__, __LINE__, PEAR_LOG_EMERG);
-                Horde::fatal(PEAR::raiseError(_("Unable to add extra user information when signing up.")), __FILE__, __LINE__);
+                Horde::fatal(_("Unable to add extra user information when signing up."), __FILE__, __LINE__);
             }
         }
 
@@ -222,7 +222,7 @@ class Auth_Signup {
  * instead of extending DataTreeObject directly.
  *
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.38.2.1 $
+ * @version $Revision: 1.38.2.2 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -261,7 +261,7 @@ class DataTreeObject_Signup extends DataTreeObject {
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Marko Djukic <marko@oblo.com>
- * @version $Revision: 1.38.2.1 $
+ * @version $Revision: 1.38.2.2 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
