@@ -11,7 +11,7 @@
  *                   DEFAULT: /bin/su
  *
  *
- * $Horde: framework/Auth/Auth/login.php,v 1.3.10.1 2005/01/03 12:18:52 jan Exp $
+ * $Horde: framework/Auth/Auth/login.php,v 1.3.10.3 2005/03/22 11:46:00 jan Exp $
  *
  * Copyright 2004-2005 Jan Schneider <jan@horde.org>
  *
@@ -19,7 +19,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.3.10.1 $
+ * @version $Revision: 1.3.10.3 $
  * @since   Horde 3.0
  * @package Horde_Auth
  */
@@ -85,15 +85,14 @@ class Auth_login extends Auth {
     function _authenticate($userId, $credentials)
     {
         if (empty($credentials['password'])) {
-            Horde::fatal(PEAR::raiseError(_("No password provided for Login authentication.")), __FILE__, __LINE__);
+            Horde::fatal(_("No password provided for Login authentication."), __FILE__, __LINE__);
         }
 
-        $proc = popen($this->_location . ' ' . $userId, 'w');
+        $proc = popen($this->_location . ' -c /bin/true ' . $userId, 'w');
         if (!is_resource($proc)) {
             return false;
         }
         fwrite($proc, $credentials['password']);
-        fwrite($proc, 'exit');
  
         return pclose($proc) === 0;
     }
