@@ -2,16 +2,15 @@
 /**
  * Horde_Data implementation for comma-separated data (CSV).
  *
- * $Horde: framework/Data/Data/csv.php,v 1.30.10.1 2005/01/03 12:18:57 jan Exp $
+ * $Horde: framework/Data/Data/csv.php,v 1.30.10.2 2005/01/24 17:58:53 jan Exp $
  *
  * Copyright 1999-2005 Jan Schneider <jan@horde.org>
  *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you did
+ * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.30.10.1 $
  * @since   Horde 1.3
  * @package Horde_Data
  */
@@ -21,15 +20,18 @@ class Horde_Data_csv extends Horde_Data {
     var $_contentType = 'text/comma-separated-values';
 
     /**
-     * Tries to dicover the CSV file's parameters.
+     * Tries to discover the CSV file's parameters.
      *
      * @access public
-     * @param string $filename  The name of the file to investigate
-     * @return array            An associative array with the following
-     *                          possible keys:
+     *
+     * @param string $filename  The name of the file to investigate.
+     *
+     * @return array  An associative array with the following possible keys:
+     * <pre>
      * 'sep':    The field seperator
      * 'quote':  The quoting character
      * 'fields': The number of fields (columns)
+     * </pre>
      */
     function discoverFormat($filename)
     {
@@ -46,17 +48,19 @@ class Horde_Data_csv extends Horde_Data {
      *
      * @access public
      *
-     * @param string  $filename  The name of the file to parse
-     * @param boolean $header    Does the first line contain the field/column names?
-     * @param string  $sep       The field/column seperator
-     * @param string  $quote     The quoting character
-     * @param integer $fields    The number or fields/columns
+     * @param string $filename  The name of the file to parse
+     * @param boolean $header   Does the first line contain the field/column
+     *                          names?
+     * @param string $sep       The field/column seperator
+     * @param string $quote     The quoting character
+     * @param integer $fields   The number or fields/columns
      *
-     * @return array             A two-dimensional array of all imported data rows.
-     *                           If $header was true the rows are associative arrays
-     *                           with the field/column names as the keys.
+     * @return array  A two-dimensional array of all imported data rows.  If
+     *                $header was true the rows are associative arrays with the
+     *                field/column names as the keys.
      */
-    function importFile($filename, $header = false, $sep = '', $quote = '', $fields = null, $import_mapping = array())
+    function importFile($filename, $header = false, $sep = '', $quote = '',
+                        $fields = null, $import_mapping = array())
     {
         @include_once('File/CSV.php');
 
@@ -64,8 +68,7 @@ class Horde_Data_csv extends Horde_Data {
 
         /* File_CSV is present. */
         if (class_exists('File_CSV')) {
-            /* File_CSV is a bit picky at what parameter it
-               expects. */
+            /* File_CSV is a bit picky at what parameter it expects. */
             $conf = array();
             if (!empty($quote)) {
                 $conf['quote'] = $quote;
@@ -85,9 +88,15 @@ class Horde_Data_csv extends Horde_Data {
              * names. */
             if ($header) {
                 $head = File_CSV::read($filename, $conf);
+                if (is_a($head, 'PEAR_Error')) {
+                    return $head;
+                }
             }
 
             while ($line = File_CSV::read($filename, $conf)) {
+                if (is_a($line, 'PEAR_Error')) {
+                    return $line;
+                }
                 if (!isset($head)) {
                     $data[] = $line;
                 } else {
@@ -105,7 +114,7 @@ class Horde_Data_csv extends Horde_Data {
             }
 
             $fp = File_CSV::getPointer($filename, $conf);
-            if ($fp) {
+            if ($fp && !is_a($fp, 'PEAR_Error')) {
                 rewind($fp);
             }
 
@@ -144,15 +153,14 @@ class Horde_Data_csv extends Horde_Data {
     }
 
     /**
-     * Builds a CSV file from a given data structure and returns it as
-     * a string.
+     * Builds a CSV file from a given data structure and returns it as a
+     * string.
      *
      * @access public
      *
-     * @param array   $data       A two-dimensional array containing the data
-     *                            set.
-     * @param boolean $header     If true, the rows of $data are associative
-     *                            arrays with field names as their keys.
+     * @param array $data      A two-dimensional array containing the data set.
+     * @param boolean $header  If true, the rows of $data are associative
+     *                         arrays with field names as their keys.
      *
      * @return string  The CSV data.
      */
@@ -194,17 +202,19 @@ class Horde_Data_csv extends Horde_Data {
 
     /**
      * Builds a CSV file from a given data structure and triggers its
-     * download. It DOES NOT exit the current script but only outputs
-     * the correct headers and data.
+     * download.  It DOES NOT exit the current script but only outputs the
+     * correct headers and data.
      *
      * @access public
      *
-     * @param string  $filename   The name of the file to be downloaded.
-     * @param array   $data       A two-dimensional array containing the data set.
-     * @param boolean $header     If true, the rows of $data are associative arrays
-     *                            with field names as their keys.
+     * @param string $filename  The name of the file to be downloaded.
+     * @param array $data       A two-dimensional array containing the data
+     *                          set.
+     * @param boolean $header   If true, the rows of $data are associative
+     *                          arrays with field names as their keys.
      */
-    function exportFile($filename, $data, $header = false, $export_mapping = array())
+    function exportFile($filename, $data, $header = false,
+                        $export_mapping = array())
     {
         $export = $this->exportData($data, $header, $export_mapping);
         $GLOBALS['browser']->downloadHeaders($filename, 'application/csv', false, strlen($export));
@@ -212,15 +222,14 @@ class Horde_Data_csv extends Horde_Data {
     }
 
     /**
-     * Takes all necessary actions for the given import step,
-     * parameters and form values and returns the next necessary step.
+     * Takes all necessary actions for the given import step, parameters and
+     * form values and returns the next necessary step.
      *
      * @access public
      *
-     * @param integer $action        The current step. One of the IMPORT_*
-     *                               constants.
-     * @param optonal array $param   An associative array containing needed
-     *                               parameters for the current step.
+     * @param integer $action  The current step. One of the IMPORT_* constants.
+     * @param array $param     An associative array containing needed
+     *                         parameters for the current step.
      *
      * @return mixed  Either the next step as an integer constant or imported
      *                data set after the final step.
@@ -234,8 +243,8 @@ class Horde_Data_csv extends Horde_Data {
                 return $next_step;
             }
 
-            /* Move uploaded file so that we can read it again in the
-               next step after the user gave some format details. */
+            /* Move uploaded file so that we can read it again in the next
+               step after the user gave some format details. */
             $file_name = Horde::getTempFile('import', false);
             if (!move_uploaded_file($_FILES['import_file']['tmp_name'], $file_name)) {
                 return PEAR::raiseError(_("The uploaded file could not be saved."));
@@ -249,8 +258,7 @@ class Horde_Data_csv extends Horde_Data {
             }
             $_SESSION['import_data'] = array_merge($_SESSION['import_data'], $conf);
 
-            /* Read the file's first two lines to show them to the
-               user. */
+            /* Read the file's first two lines to show them to the user. */
             $_SESSION['import_data']['first_lines'] = '';
             $fp = @fopen($file_name, 'r');
             if ($fp) {
