@@ -44,13 +44,16 @@ if (!defined('LATT_HASCHILDREN')) {
 /* The manner to which to traverse the tree when calling next(). */
 /** @const IMAPTREE_NEXT_SHOWCLOSED */   define('IMAPTREE_NEXT_SHOWCLOSED', 1);
 
+/* The string used to indicate the base of the tree. */
+/** @const IMAPTREE_BASE_ELT */ define('IMAPTREE_BASE_ELT', null);
+
 /**
  * The IMAP_Tree class provides a tree view of the folders supported with
  * the PHP imap extension (IMAP/POP3/NNTP repositories).  It provides access
  * functions to iterate through this tree and query information about
  * individual mailboxes/folders.
  *
- * $Horde: framework/IMAP/IMAP/Tree.php,v 1.48.2.2 2005/01/03 12:19:02 jan Exp $
+ * $Horde: framework/IMAP/IMAP/Tree.php,v 1.48.2.11 2005/03/25 03:19:54 slusarz Exp $
  *
  * Copyright 2000-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2000-2005 Jon Parise <jon@horde.org>
@@ -64,7 +67,6 @@ if (!defined('LATT_HASCHILDREN')) {
  * @author  Jon Parise <jon@horde.org>
  * @author  Anil Madhavapeddy <avsm@horde.org>
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.48.2.2 $
  * @since   Horde 3.0
  * @package Horde_IMAP
  */
@@ -88,13 +90,6 @@ class IMAP_Tree {
     var $_currkey = null;
     var $_currstack = array();
 
-    /**
-     * Key of first (top?) element in the tree (for traversal).
-     *
-     * @var string $_first
-     */
-    var $_first = '';
-
     /**
      * Show unsubscribed mailboxes?
      *
@@ -399,7 +394,7 @@ class IMAP_Tree {
      */
     function _getMailbox($path)
     {
-        $box = (!$this->_showunsub && (($this->_mode == IMAPTREE_MODE_NEWS) || (strcasecmp($path, 'INBOX') != 0))) ? @imap_getsubscribed($this->_getStream(), $this->_server, $path) : @imap_getmailboxes($this->_getStream(), $this->_server, $path);
+        $box = (!$this->_showunsub && ($this->_convertName($path) == 'INBOX')) ? @imap_getsubscribed($this->_getStream(), $this->_server, $path) : @imap_getmailboxes($this->_getStream(), $this->_server, $path);
 
         if (empty($box)) {
             return false;
@@ -436,14 +431,13 @@ class IMAP_Tree {
     function _makeMailboxTreeElt($ob)
     {
         $elt['a'] = $ob->attributes;
-        $elt['p'] = null;
+        $elt['p'] = IMAPTREE_BASE_ELT;
         $elt['v'] = $ob->name;
 
         /* Set subscribed values. Make sure INBOX is always subscribed
          * to (if working with mail) so there is always at least 1
          * viewable element. */
-        if (($this->_mode == IMAPTREE_MODE_MAIL) &&
-            (strcasecmp($ob->name, 'INBOX') == 0)) {
+        if ($elt['v'] == 'INBOX') {
             $this->_initSubscribed();
             $this->_setSubscribed($elt, true);
         } elseif (!$this->isSubscribed($elt)) {
@@ -490,7 +484,6 @@ class IMAP_Tree {
         $this->_currkey = null;
         $this->_currparent = null;
         $this->_currstack = array();
-        $this->_first = null;
         $this->_tree = array();
         $this->_parent = array();
         $this->_showunsub = $this->_unsubview = ($init & IMAPTREE_INIT_UNSUB);
@@ -505,6 +498,10 @@ class IMAP_Tree {
         /* Get the initial list of mailboxes from the subclass. */
         $boxes = $this->_init();
 
+        /* Create a placeholder element to the base of the tree list so we can
+         * keep track of whether the base level needs to be sorted. */
+        $this->_tree[IMAPTREE_BASE_ELT] = array('a' => 0);
+
         /* Create the list (INBOX and any other hierarchies). */
         $this->_addLevel($boxes);
 
@@ -556,6 +553,8 @@ class IMAP_Tree {
      */
     function expand($folder, $expandall = false)
     {
+        $folder = $this->_convertName($folder);
+
         if (!isset($this->_tree[$folder])) {
             return;
         }
@@ -600,6 +599,8 @@ class IMAP_Tree {
      */
     function collapse($folder)
     {
+        $folder = $this->_convertName($folder);
+
         if (!isset($this->_tree[$folder])) {
             return;
         }
@@ -634,15 +635,15 @@ class IMAP_Tree {
 
         if ($this->_activeElt($curr) &&
             (($mask & IMAPTREE_NEXT_SHOWCLOSED) || $this->isOpen($curr)) &&
-            ($this->_currparent != $curr['value'])) {
+            ($this->_currparent != $curr['v'])) {
             /* If the current element is open, and children exist, move into
              * it. */
             array_push($this->_currstack, array('k' => $this->_currkey, 'p' => $this->_currparent));
             $this->_currkey = 0;
-            $this->_currparent = $curr['value'];
-            if ($this->_needSort($this->_tree[$curr['value']])) {
-                $this->_sortList($this->_parent[$curr['value']]);
-                $this->_setNeedSort($this->_tree[$curr['value']], false);
+            $this->_currparent = $curr['v'];
+            if ($this->_needSort($this->_tree[$curr['v']])) {
+                $this->_sortList($this->_parent[$curr['v']]);
+                $this->_setNeedSort($this->_tree[$curr['v']], false);
                 $this->_changed = true;
             }
         } else {
@@ -692,20 +693,14 @@ class IMAP_Tree {
      */
     function reset()
     {
-        foreach ($this->_parent as $key => $val) {
-            $key2 = array_search($this->_first, $val);
-            if ($key2 !== null) {
-                $this->_currkey = $key2;
-                $this->_currparent = $key;
-                $this->_currstack = array();
-                if (isset($this->_tree[$key]) &&
-                    $this->_needSort($this->_tree[$key])) {
-                    $this->_sortList($this->_parent[$key]);
-                    $this->_setNeedSort($this->_tree[$key], false);
-                    $this->_changed = true;
-                }
-                break;
-            }
+        $this->_currkey = 0;
+        $this->_currparent = null;
+        $this->_currstack = array();
+
+        if ($this->_needSort($this->_tree[$this->_currparent])) {
+            $this->_sortList($this->_parent[$this->_currparent]);
+            $this->_setNeedSort($this->_tree[$this->_currparent], false);
+            $this->_changed = true;
         }
 
         return $this->current();
@@ -778,6 +773,8 @@ class IMAP_Tree {
      */
     function get($name)
     {
+        $name = $this->_convertName($name);
+
         if (isset($this->_tree[$name])) {
             return $this->_addAliases($this->_tree[$name]);
         } else {
@@ -798,9 +795,11 @@ class IMAP_Tree {
     function insert($id)
     {
         if (is_array($id)) {
-            /* We want to add from the BASE of the tree up for efficiency
-             * sake. */
-            $this->_sortList($id);
+            if (!$this->_nonimapelt) {
+                /* We want to add from the BASE of the tree up for efficiency
+                 * sake. */
+                $this->_sortList($id);
+            }
         } else {
             $id = array($id);
         }
@@ -834,14 +833,11 @@ class IMAP_Tree {
         /* Break apart the name via the delimiter and go step by step through
          * the name to make sure all subfolders exist in the tree. */
         $parts = explode($this->_delimiter, $id);
+        $parts[0] = $this->_convertName($parts[0]);
         $begin = implode($this->_delimiter, array_slice($parts, 0, $pos));
         $more = (count($parts) > $pos);
 
-        if (isset($this->_tree[$begin])) {
-            if (!$more) {
-                $this->_setContainer($this->_tree[$begin], false);
-            }
-        } elseif ($begin != $this->_prefixnodelim) {
+        if (!isset($this->_tree[$begin]) && ($begin != $this->_prefixnodelim)) {
             if ($this->_nonimapelt) {
                 $elt = $this->_getNonIMAPElt($begin);
             } else {
@@ -925,10 +921,11 @@ class IMAP_Tree {
                 }
             }
             return $success;
+        } else {
+            $id = $this->_convertName($id);
         }
 
-        if ((($this->_mode == IMAPTREE_MODE_MAIL) &&
-             (strcasecmp($id, 'INBOX') == 0)) ||
+        if (($id == 'INBOX') ||
             !isset($this->_tree[$id]) ||
             ($id == $this->_prefixnodelim)) {
             return false;
@@ -960,9 +957,12 @@ class IMAP_Tree {
              * the tree. */
             unset($this->_parent[$parent]);
             if (isset($this->_tree[$parent])) {
-                $this->_setChildren($this->_tree[$parent], false);
                 if ($this->isContainer($this->_tree[$parent])) {
                     $this->delete($parent);
+                } else {
+                    $this->_removeExpandedList($parent);
+                    $this->_setChildren($this->_tree[$parent], false);
+                    $this->_setOpen($this->_tree[$parent], false);
                 }
             }
         } else {
@@ -993,7 +993,9 @@ class IMAP_Tree {
         }
 
         foreach ($id as $val) {
+            $val = $this->_convertName($val);
             if (isset($this->_tree[$val])) {
+                $this->_changed = true;
                 $this->_setSubscribed($this->_tree[$val], true);
                 $this->_setContainer($this->_tree[$val], false);
                 if (!is_null($this->_subscribed)) {
@@ -1025,10 +1027,13 @@ class IMAP_Tree {
         }
 
         foreach ($id as $val) {
+            $val = $this->_convertName($val);
+
             /* INBOX can never be unsubscribed to (if in mail mode). */
-            if (isset($this->_tree[$val]) &&
-                (($this->_mode != IMAPTREE_MODE_MAIL) ||
-                 (strcasecmp($val, 'INBOX') != 0))) {
+            if (isset($this->_tree[$val]) && ($val != 'INBOX')) {
+                $this->_changed = true;
+                $this->_unsubview = true;
+
                 $elt = &$this->_tree[$val];
 
                 /* Do not delete from tree if there are child elements -
@@ -1059,24 +1064,17 @@ class IMAP_Tree {
     function _addLevel($list)
     {
         $expandall = ($this->_initmode & IMAPTREE_INIT_FETCHALL);
-        foreach ($list as $key => $val) {
+        $isparent = false;
+
+        foreach ($list as $val) {
             $elt = $this->_makeMailboxTreeElt($val);
-            if ($key != $this->_prefix) {
-                /* We need to convert $parent to a string because, if there
-                 * is no parent (NULL), this is stored as the empty string in
-                 * the parent array. */
-                $parent = strval($elt['p']);
-                if ($this->_insertElt($elt) && empty($this->_first)) {
-                    $this->_first = $elt['l'];
+            $isparent = true;
+            $parent = $elt['p'];
+            $this->_insertElt($elt);
 
-                    /* If this is the base level, add a placeholder element to
-                     * the tree list so we can keep track of whether the base
-                     * level needs to be sorted. */
-                    $this->_tree[$parent] = array('a' => 0);
-                }
-            }
-
-            if ($expandall || $this->isOpen($elt)) {
+            /* See Bug #1620 for the reason we have the NOINFERIORS check. */
+            if (($expandall || $this->isOpen($elt)) &&
+                !($elt['a'] & LATT_NOINFERIORS)) {
                 $this->expand($elt['v']);
             } else {
                 $this->_childrenInfo($elt['v'], false, true);
@@ -1084,7 +1082,7 @@ class IMAP_Tree {
         }
 
         /* Sort the list. */
-        if (isset($parent) &&
+        if ($isparent &&
             !empty($this->_parent[$parent]) &&
             (count($this->_parent[$parent]) > 1)) {
             $this->_setNeedSort($this->_tree[$parent], true);
@@ -1343,7 +1341,7 @@ class IMAP_Tree {
     function _removeServerString($ob)
     {
         $ob->fullServerPath = $ob->name;
-        $ob->name = substr($ob->name, strpos($ob->name, '}') + 1);
+        $ob->name = $this->_convertName(substr($ob->name, strpos($ob->name, '}') + 1));
         return $ob;
     }
 
@@ -1585,8 +1583,7 @@ class IMAP_Tree {
         }
 
         if (!$tried || ($info['haschildren'] && $list)) {
-            if (($this->_mode == IMAPTREE_MODE_MAIL) &&
-                (strcasecmp($id, 'INBOX') == 0) &&
+            if (($id == 'INBOX') &&
                 (!empty($this->_prefix) || !empty($this->_namespace))) {
                 if (!empty($this->_prefix)) {
                     $query = $this->_prefix . '%';
@@ -1601,7 +1598,7 @@ class IMAP_Tree {
             if (!$info['haschildren']) {
                 if (!empty($info['list'])) {
                     $info['haschildren'] = true;
-                } elseif (strcasecmp($id, 'INBOX') == 0) {
+                } elseif ($id == 'INBOX') {
                     /* Check to see if INBOX's children reside under the
                      * same level as the INBOX. */
                     $ret = $this->_getList('%');
@@ -1631,6 +1628,7 @@ class IMAP_Tree {
         }
 
         $this->_showunsub = $unsub;
+        $this->_changed = true;
 
         /* If we are switching from unsubscribed to subscribed, no need
          * to do anything (we just ignore unsubscribed stuff). */
@@ -1764,8 +1762,23 @@ class IMAP_Tree {
     {
         return ($this->_showunsub ||
                 $this->isSubscribed($elt) ||
-                ($this->isContainer($elt) &&
+                (($this->_unsubview || $this->isContainer($elt)) &&
                  $this->hasChildren($elt, true)));
     }
 
+    /**
+     * Convert a mailbox name to the correct, internal name (i.e. make sure
+     * INBOX is always capitalized for IMAP servers).
+     *
+     * @access private
+     *
+     * @param string $name  The mailbox name.
+     *
+     * @return string  The converted name.
+     */
+    function _convertName($name)
+    {
+        return (($this->_mode == IMAPTREE_MODE_MAIL) && (strcasecmp($name, 'INBOX') == 0)) ? 'INBOX' : $name;
+    }
+
 }
