@@ -10,7 +10,7 @@
  * class         -- CSS class of the generated <a> tag.  Defaults to none.
  * </pre>
  *
- * $Horde: framework/Text_Filter/Filter/emails.php,v 1.15.10.1 2005/01/03 12:19:16 jan Exp $
+ * $Horde: framework/Text_Filter/Filter/emails.php,v 1.15.10.3 2005/03/21 18:57:57 jan Exp $
  *
  * Copyright 2003-2005 Tyler Colbert <tyler-hordeml@colberts.us>
  * Copyright 2004-2005 Jan Schneider <jan@horde.org>
@@ -20,7 +20,6 @@
  *
  * @author Tyler Colbert <tyler-hordeml@colberts.us>
  * @author Jan Schneider <jan@horde.org>
- * @version $Revision: 1.15.10.1 $
  * @package Horde_Text
  */
 class Text_Filter_emails extends Text_Filter {
@@ -62,7 +61,7 @@ class Text_Filter_emails extends Text_Filter {
 
             |
             # Version 2 Pattern 8: simple email addresses.
-            (\b[\w-.=]+@[-A-Z0-9.]*[A-Z0-9])
+            (\b[\w-+.=]+@[-A-Z0-9.]*[A-Z0-9])
             # Pattern 9 to 11: Optional parameters
             ((\?)([^\s"<]*[\w+#?\/&=]))?
 
