@@ -1,8 +1,18 @@
 <?php
+
+require_once 'Horde/String.php';
+
 /**
  * Takes HTML and converts it to formatted, plain text.
  *
- * $Horde: framework/Text_Filter/Filter/html2text.php,v 1.4.10.1 2005/01/03 12:19:16 jan Exp $
+ * Parameters:
+ * <pre>
+ * charset -- The charset to use for html_entity_decode() calls.
+ * width   -- The wrapping width.
+ * wrap    -- Whether to wrap the text or not.
+ * </pre>
+ *
+ * $Horde: framework/Text_Filter/Filter/html2text.php,v 1.4.10.6 2005/03/14 18:10:37 jan Exp $
  *
  * Copyright 2003-2005 Jon Abernathy <jon@chuggnutt.com>
  * Original source: http://www.chuggnutt.com/html2text.php
@@ -13,7 +23,6 @@
  *
  * @author  Jon Abernathy <jon@chuggnutt.com>
  * @author  Jan Schneider <jan@horde.org>
- * @version $Revision: 1.4.10.1 $
  * @since   Horde 3.0
  * @package Horde_Text
  */
@@ -24,7 +33,9 @@ class Text_Filter_html2text extends Text_Filter {
      *
      * @var array $_params
      */
-    var $_params = array('width' => 70);
+    var $_params = array('charset' => null,
+                         'width' => 70,
+                         'wrap' => true);
 
     /**
      * Executes any code necessaray before applying the filter patterns.
@@ -37,8 +48,12 @@ class Text_Filter_html2text extends Text_Filter {
     {
         global $_html2text_state;
 
+        if (is_null($this->_params['charset'])) {
+            $this->_params['charset'] = isset($GLOBALS['_HORDE_STRING_CHARSET']) ? $GLOBALS['_HORDE_STRING_CHARSET'] : 'ISO-8859-1';
+        }
+
         $_html2text_state['linkList'] = '';
-        $_html2text_state['linkCount'] = 1;
+        $_html2text_state['linkCount'] = 0;
 
         return trim($text);
     }
@@ -76,16 +91,16 @@ class Text_Filter_html2text extends Text_Filter {
             //'/<!-- .* -->/' => '',
 
             // h1 - h3
-            '/<h[123][^>]*>(.+?)<\/h[123]>/ie' => "strtoupper(\"\n\n\\1\n\n\")",
+            '/<h[123][^>]*>(.+?)<\/h[123]> ?/ie' => "strtoupper(\"\n\n\\1\n\n\")",
 
             // h4 - h6
-            '/<h[456][^>]*>(.+?)<\/h[456]>/ie' => "ucwords(\"\n\n\\1\n\n\")",
+            '/<h[456][^>]*>(.+?)<\/h[456]> ?/ie' => "ucwords(\"\n\n\\1\n\n\")",
 
             // <p>
-            '/<p[^>]*>/i' => "\n\n  ",
+            '/<p[^>]*> ?/i' => "\n\n  ",
 
             // <br>
-            '/<br[^>]*> /i' => "\n",
+            '/<br[^>]*> ?/i' => "\n",
 
             // <b>
             '/<b[^>]*>(.+?)<\/b>/ie' => 'strtoupper("\\1")',
@@ -95,40 +110,45 @@ class Text_Filter_html2text extends Text_Filter {
             '/<span\\s+style="font-weight:\\s*bold.*">(.+?)<\/span>/ie' => 'strtoupper("\\1")',
 
             // <i>
-            '/<i[^>]*>(.+?)<\/i>/i' => '_\\1_',
+            '/<i[^>]*>(.+?)<\/i>/i' => '/\\1/',
 
             // <em>
-            '/<em[^>]*>(.+?)<\/em>/i' => '_\\1_',
+            '/<em[^>]*>(.+?)<\/em>/i' => '/\\1/',
+
+            // <u>
+            '/<u[^>]*>(.+?)<\/u>/i' => '_\\1_',
 
             // <ul>/<ol> and </ul>/</ol>
-            '/(<(u|o)l[^>]*>| ?<\/(u|o)l>)/i' => "\n\n",
+            '/(<(u|o)l[^>]*>| ?<\/(u|o)l>) ?/i' => "\n\n",
 
             // <li>
             '/ ?<li[^>]*>/i' => "\n  * ",
 
             // <a href="">
-            '/ ?<a href="([^"]+)"[^>]*>(.+?)<\/a>/ie' => 'Text_Filter_html2text::_buildLinkList($GLOBALS["_html2text_state"]["linkCount"], "\\1", "\\2")',
+            '/<a href="([^"]+)"[^>]*>(.+?)<\/a>/ie' => 'Text_Filter_html2text::_buildLinkList($GLOBALS["_html2text_state"]["linkCount"], "\\1", "\\2")',
 
             // <hr>
-            '/<hr[^>]*>/i' => "\n-------------------------\n",
+            '/<hr[^>]*> ?/i' => "\n-------------------------\n",
 
             // <table> and </table>
-            '/(<table[^>]*>| ?<\/table>)/i' => "\n\n",
+            '/(<table[^>]*>| ?<\/table>) ?/i' => "\n\n",
 
             // <tr>
-            '/ ?<tr[^>]*>/i' => "\n\t",
+            '/ ?<tr[^>]*> ?/i' => "\n\t",
 
             // <td> and </td>
             '/ ?<td[^>]*>(.+?)<\/td> ?/i' => "\\1\t\t",
             '/\t\t<\/tr>/i' => '',
 
+            // entities
             '/&nbsp;/i' => ' ',
-            '/&quot;/i' => '"',
-            '/&gt;/i' => '>',
-            '/&lt;/i' => '<',
-            '/&amp;/i' => '&',
             '/&copy;/i' => '(c)',
-            '/&trade;/i' => '(tm)'
+            '/&trade;/i' => '(tm)',
+            '/&#(\d+);/e' => 'String::convertCharset(Text_Filter_html2text::_int2utf8("\\1"), "UTF-8", "' . $this->_params['charset'] . '")',
+
+            // Some mailers (e.g. Hotmail) use the following div tag as a way
+            // to define a block of text.
+            '/<div class=rte>(.+?)<\/div> ?/i' => "\\1\n"
         );
 
         return array('regexp' => $regexp);
@@ -149,21 +169,52 @@ class Text_Filter_html2text extends Text_Filter {
         /* Strip any other HTML tags. */
         $text = strip_tags($text);
 
+        /* Convert html entities. */
+        $text = @html_entity_decode($text, ENT_QUOTES, $this->_params['charset']);
+
         /* Bring down number of empty lines to 2 max. */
         $text = preg_replace("/\n[[:space:]]+\n/", "\n\n", $text);
         $text = preg_replace("/[\n]{3,}/", "\n\n", $text);
 
         /* Add link list. */
         if (!empty($_html2text_state['linkList'])) {
-            $text .= "\n\n" . _("Links") . ":\n------\n" . $_html2text_state['linkList'];
+            $text .= "\n\n" . _("Links") . ":\n" . str_repeat('-', String::length(_("Links")) + 1) . "\n" . $_html2text_state['linkList'];
         }
 
         /* Wrap the text to a readable format. */
-        $text = wordwrap($text, $this->_params['width']);
+        if ($this->_params['wrap']) {
+            $text = wordwrap($text, $this->_params['width']);
+        }
 
         return $text;
     }
 
+    /**
+     * Returns the UTF-8 character sequence of a Unicode value.
+     *
+     * @param int $num  A Unicode value.
+     *
+     * @return string  The UTF-8 string.
+     */
+    function _int2utf8($num)
+    {
+        if ($num < 128) {
+            return chr($num);
+        }
+        if ($num < 2048) {
+            return chr(($num >> 6) + 192) . chr(($num & 63) + 128);
+        }
+        if ($num < 65536) {
+            return chr(($num >> 12) + 224) . chr((($num >> 6) & 63) + 128) .
+                chr(($num & 63) + 128);
+        }
+        if ($num < 2097152) {
+            return chr(($num >> 18) + 240) . chr((($num >> 12) & 63) + 128) .
+                chr((($num >> 6) & 63) + 128) . chr(($num & 63) + 128);
+        }
+        return '';
+    }
+
     /**
      * Helper function called by preg_replace() on link replacement.
      *
