@@ -7,10 +7,9 @@ require_once dirname(__FILE__) . '/rcs.php';
  *
  * Copyright 2000-2005 Anil Madhavapeddy, <anil@recoil.org>
  *
- * $Horde: framework/VC/VC/cvs.php,v 1.32.2.1 2005/01/03 12:19:20 jan Exp $
+ * $Horde: framework/VC/VC/cvs.php,v 1.32.2.5 2005/02/02 18:46:04 chuck Exp $
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.32.2.1 $
  * @package VC
  */
 class VC_cvs extends VC_rcs {
@@ -81,7 +80,6 @@ class VC_cvs extends VC_rcs {
  * Anil Madhavapeddy, <anil@recoil.org>
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.32.2.1 $
  * @package VC
  */
 class VC_Annotate_cvs {
@@ -188,7 +186,6 @@ class VC_Annotate_cvs {
  * Anil Madhavapeddy, <anil@recoil.org>
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.32.2.1 $
  * @package VC
  */
 class VC_Checkout_cvs {
@@ -428,7 +425,9 @@ class VC_Directory_cvs {
             } elseif (@is_file($path) && substr($name, -2) == ',v') {
                 /* Spawn a new file object to represent this file. */
                 $fl = &$this->rep->getFileObject(substr($path, strlen($this->rep->sourceroot()), -2), $cache, $quicklog);
-                if (!is_a($fl, 'PEAR_Error')) {
+                if (is_a($fl, 'PEAR_Error')) {
+                    return $fl;
+                } else {
                     $this->files[] = &$fl;
                 }
             }
@@ -508,7 +507,7 @@ class VC_Directory_cvs {
         $bb = $b->queryLastLog();
         if ($aa->queryDate() == $bb->queryDate()) {
             return 0;
-        } elseif ($this->sortDir = VC_SORT_ASCENDING) {
+        } elseif ($this->sortDir == VC_SORT_ASCENDING) {
             return ($aa->queryDate() < $bb->queryDate()) ? 1 : -1;
         } else {
             return ($bb->queryDate() < $aa->queryDate()) ? 1 : -1;
