@@ -2,14 +2,14 @@
 /**
  * Net_IMSP_Utils::
  *
- * $Horde: framework/Net_IMSP/IMSP/Utils.php,v 1.3.10.1 2005/01/03 12:19:08 jan Exp $
+ * $Horde: framework/Net_IMSP/IMSP/Utils.php,v 1.3.10.3 2005/02/27 17:40:23 mrubinsk Exp $
  *
- * Copyright 2003-2005 Michael Rubinsky <mike@theupstairsroom.com>
+ * Copyright 2003-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
- * @author  Michael Rubinsky <mike@theupstairsroom.com>
+ * @author  Michael Rubinsky <mrubinsk@horde.org>
  * @package Net_IMSP
  */
 class Net_IMSP_Utils {
@@ -24,12 +24,12 @@ class Net_IMSP_Utils {
      * @param array $serverInfo  Information about the server
      *                           and the current user.
      *
-     * @return array  Information about all the addressbooks.
+     * @return array  Information about all the addressbooks or PEAR_Error.
      */
     function getAllBooks($serverInfo)
     {
         require_once 'Net/IMSP.php';
-
+        $foundDefault = false;
         $results = array();
         $imsp = &Net_IMSP::singleton('Book', $serverInfo['params']);
         $result = $imsp->init();
@@ -39,6 +39,9 @@ class Net_IMSP_Utils {
         }
 
         $books = $imsp->getAddressBookList();
+        if (is_a($books, 'PEAR_Error')) {
+            return $books;
+        }
 
         for ($i = 0; $i < count($books); $i++) {
             if ($books[$i] != $serverInfo['params']['username']) {
@@ -52,9 +55,15 @@ class Net_IMSP_Utils {
                 }
 
                 $results[] = $newBook;
+            } else {
+                $foundDefault = true;
             }
         }
-
+        /* For our purposes, no default addressbook means auth must have failed
+         * probably due to bad username*/
+        if (!$foundDefault) {
+            return PEAR::raiseError(IMSP_EXIT_LOGIN_FAILED . ': Default addressbook is missing!');
+        }
         return $results;
     }
 
