@@ -8,7 +8,7 @@
  * See the enclosed file COPYING for license information (GPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * $Horde: horde/templates/javascript/tree.js,v 1.62.2.2 2005/01/03 12:25:46 jan Exp $
+ * $Horde: horde/templates/javascript/tree.js,v 1.62.2.6 2005/03/15 02:30:43 chuck Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @package Horde_Tree
@@ -176,19 +176,16 @@ Horde_Tree.prototype.buildTree = function(nodeId)
 Horde_Tree.prototype.buildLine = function(nodeId)
 {
     var style = '';
-    var rowClass = '';
+    var rowClass = 'treeRow';
     if (this.nodes[nodeId]['class']) {
-        rowClass = this.nodes[nodeId]['class'];
+        rowClass += ' ' + this.nodes[nodeId]['class'];
     }
     if (this.options['alternate']) {
         rowClass += ' item' + this.altCount;
         this.altCount = 1 - this.altCount;
     }
-    if (rowClass) {
-        rowClass = ' class="' + rowClass + '"';
-    }
 
-    var line = '<div style="height:20px;clear:both"' + rowClass + '>';
+    var line = '<div class="' + rowClass + '">';
 
     /* If we have headers, track which logical "column" we're in
      * for any given cell of content. */
@@ -241,7 +238,7 @@ Horde_Tree.prototype.buildLine = function(nodeId)
             line += '<img src="' + this.imgDir + '/' + this.imgBlank + '" alt="&nbsp;&nbsp;&nbsp;" height="20" width="20" style="vertical-align:middle" />';
         }
     }
-    line += this._setNodeToggle(nodeId) + this._setNodeIcon(nodeId);
+    line += this._setNodeToggle(nodeId);
     if (this.options['multiline']) {
         line += '</td><td>';
     }
@@ -312,9 +309,9 @@ Horde_Tree.prototype._setLabel = function(nodeId)
             onclick = ' onclick="' + this.nodes[nodeId]['onclick'] + '"';
         }
 
-        return '<a' + urlClass + ' href="' + this.nodes[nodeId]['url'] + '"' + target + onclick + '>' + label + '</a>';
+        return '<a' + urlClass + ' href="' + this.nodes[nodeId]['url'] + '"' + target + onclick + '>' + this._setNodeIcon(nodeId) + label + '</a>';
     } else {
-        return '<span style="cursor:pointer;vertical-align:middle" onclick="' + this._instanceName + '.toggle(\'' + nodeId + '\')">' + label + '</span>';
+        return '<span style="cursor:pointer;vertical-align:middle" onclick="' + this._instanceName + '.toggle(\'' + nodeId + '\')">' + this._setNodeIcon(nodeId) + label + '</span>';
     }
 }
 
@@ -381,7 +378,7 @@ Horde_Tree.prototype._getNodeToggle = function(nodeId)
             nodeToggle[1] = '&nbsp;&nbsp;&nbsp;'
         } else if (this.nodes[nodeId]['expanded']) {
             nodeToggle[0] = this.imgMinusOnly;
-            nodeToggle[1] = '&#8211;';
+            nodeToggle[1] = '-';
         } else {
             nodeToggle[0] = this.imgPlusOnly;
             nodeToggle[1] = '+';
@@ -393,7 +390,7 @@ Horde_Tree.prototype._getNodeToggle = function(nodeId)
             /* Not last node. */
             if (this.options['lines']) {
                 nodeToggle[0] = this.imgJoin;
-                nodeToggle[1] = "|-";
+                nodeToggle[1] = '|-';
             } else {
                 nodeToggle[0] = this.imgBlank;
                 nodeToggle[1] = '&nbsp;&nbsp;&nbsp;';
@@ -402,7 +399,7 @@ Horde_Tree.prototype._getNodeToggle = function(nodeId)
             /* Last node. */
             if (this.options['lines']) {
                 nodeToggle[0] = this.imgJoinBottom;
-                nodeToggle[1] = "`-";
+                nodeToggle[1] = '`-';
             } else {
                 nodeToggle[0] = this.imgBlank;
                 nodeToggle[1] = '&nbsp;&nbsp;&nbsp;';
@@ -417,10 +414,10 @@ Horde_Tree.prototype._getNodeToggle = function(nodeId)
                 nodeToggle[1] = '&nbsp;&nbsp;&nbsp;';
             } else if (this.renderStatic) {
                 nodeToggle[0] = this.imgJoin;
-                nodeToggle[1] = "|-";
+                nodeToggle[1] = '|-';
             } else if (this.nodes[nodeId]['expanded']) {
                 nodeToggle[0] = this.imgMinus;
-                nodeToggle[1] = '&#8211;';
+                nodeToggle[1] = '-';
             } else {
                 nodeToggle[0] = this.imgPlus;
                 nodeToggle[1] = '+';
@@ -435,7 +432,7 @@ Horde_Tree.prototype._getNodeToggle = function(nodeId)
                 nodeToggle[1] = '`-';
             } else if (this.nodes[nodeId]['expanded']) {
                 nodeToggle[0] = this.imgMinusBottom;
-                nodeToggle[1] = '&#8211;';
+                nodeToggle[1] = '-';
             } else {
                 nodeToggle[0] = this.imgPlusBottom;
                 nodeToggle[1] = '+';
@@ -502,15 +499,20 @@ Horde_Tree.prototype.toggle = function(nodeId)
 {
     this.nodes[nodeId]['expanded'] = !this.nodes[nodeId]['expanded'];
     if (this.nodes[nodeId]['expanded']) {
-        document.getElementById('nodeChildren_' + nodeId).style.display = 'block';
+        if (node = document.getElementById('nodeChildren_' + nodeId)) {
+            node.style.display = 'block';
+        }
     } else {
-        document.getElementById('nodeChildren_' + nodeId).style.display = 'none';
+        if (node = document.getElementById('nodeChildren_' + nodeId)) {
+            node.style.display = 'none';
+        }
     }
 
     nodeToggle = this._getNodeToggle(nodeId);
-    toggle = document.getElementById('nodeToggle_' + nodeId);
-    toggle.src = this.imgDir + '/' + nodeToggle[0];
-    toggle.alt = nodeToggle[1];
+    if (toggle = document.getElementById('nodeToggle_' + nodeId)) {
+        toggle.src = this.imgDir + '/' + nodeToggle[0];
+        toggle.alt = nodeToggle[1];
+    }
 
     this.saveState(nodeId, this.nodes[nodeId]['expanded'])
 }
@@ -550,7 +552,7 @@ Horde_Tree.prototype._getCookie = function(name)
     } else {
         begin += 2;
     }
-    var end = document.cookie.indexOf(";", begin);
+    var end = document.cookie.indexOf(';', begin);
     if (end == -1) {
         end = dc.length;
     }
