@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/test.php,v 1.122.6.2 2005/01/04 11:39:13 jan Exp $
+ * $Horde: horde/test.php,v 1.122.6.6 2005/03/07 11:56:04 jan Exp $
  *
  * Copyright 2002-2005 Brent J. Nordquist <bjn@horde.org>
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
@@ -61,12 +61,19 @@ $module_list = array(
     'mcal' => 'MCAL Support',
     'mcrypt' => 'Mcrypt Support',
     'fileinfo' => array(
-        'descrip' => 'MIME Magic Support',
-        'error' => 'The fileinfo PECL module will most likely provide faster MIME Magic lookups than the built-in Horde PHP magic code. See horde/docs/INSTALL for information on how to install PECL extensions.'
+        'descrip' => 'MIME Magic Support (fileinfo)',
+        'error' => 'The fileinfo PECL module or the mime_magic PHP extension (see below) will most likely provide faster MIME Magic lookups than the built-in Horde PHP magic code. See horde/docs/INSTALL for information on how to install PECL/PHP extensions.'
+    ),
+    'mime_magic' => array(
+        'descrip' => 'MIME Magic Support (mime_magic)',
+        'error' => 'The fileinfo PECL module (see above) or the mime_magic PHP extension will most likely provide faster MIME Magic lookups than the built-in Horde PHP magic code. See horde/docs/INSTALL for information on how to install PECL/PHP extensions.'
     ),
     'mysql' => 'MySQL Support',
     'openssl' => 'OpenSSL Support',
     'pgsql' => 'PostgreSQL Support',
+    'session' => array(
+        'descrip' => 'Session Support',
+        'fatal' => true),
     'xml' => 'XML Support',
     'zlib' => array(
         'descrip' => 'Zlib Support',
@@ -119,7 +126,8 @@ $pear_list = array(
     'Log' => array(
         'path' => 'Log.php',
         'error' => 'Make sure you are using a version of PEAR which includes the Log classes, or that you have installed the Log package seperately. See the INSTALL file for instructions on installing Log.',
-        'required' => true
+        'required' => true,
+        'function' => '_check_pear_log_version'
     ),
     'DB' => array(
         'path' => 'DB.php',
@@ -140,7 +148,7 @@ $pear_list = array(
     ),
     'HTTP_Request' => array(
         'path' => 'HTTP/Request.php',
-        'error' => 'Parts of Horde (Jonah, the XML-RPC client/server) use the HTTP_Request library to retrieve URLs and do other HTTP requests.'
+        'error' => 'Parts of Horde (HTML composition in IMP, Jonah, the XML-RPC client/server) use the HTTP_Request library to retrieve URLs and do other HTTP requests.'
     ),
     'File' => array(
         'path' => 'File/CSV.php',
@@ -156,13 +164,19 @@ $pear_list = array(
     )
 );
 
+/* Additional check for PEAR Log module for its version. */
+function _check_pear_log_version()
+{
+    if (!defined('PEAR_LOG_INFO')) {
+        return 'Your version of Log is not recent enough.';
+    }
+}
+
 /* Additional check for PEAR DB module for its version. */
 function _check_pear_db_version()
 {
-    $peardbversion = '0';
-    $peardbversion = @DB::apiVersion();
-    if ($peardbversion < 2) {
-        return 'Your version of DB (' . $peardbversion . ') is not recent enough.';
+    if (!defined('DB_PORTABILITY_LOWERCASE')) {
+        return 'Your version of DB is not recent enough.';
     }
 }
 
